@@ -21,7 +21,6 @@ class Analytics(BaseHTTPMiddleware):
     def dispatch(self, request: Request, call_next: Callable[[Request], Response]):
         start = time()
         response = call_next(request)
-        elapsed = time() - start
 
         json = {
             'api_key': self.api_key,
@@ -30,8 +29,8 @@ class Analytics(BaseHTTPMiddleware):
             'user_agent': request.headers['user-agent'],
             'method': request.method,
             'status': response.status_code,
-            'response_time': int(elapsed * 1000),
-            'framework': 1
+            'framework': 1,
+            'response_time': int((time() - start) * 1000),
         }
         threading.Thread(target=log_request, args=(json,)).start()
         return response
